# emacs-filesystem not available until Fedora 15
%global advanced_emacs %([ 0%{?fedora} -ge 15 -o 0%{?rhel} -ge 7 ] && echo 1 || echo 0)

# For F-9 to F-16, EL-6, we install the shared library into /%%{_lib} rather than %%{_libdir}
%global library_dir %([ '(' 0%{?fedora} -ge 9 -a 0%{?fedora} -le 16 ')' -o 0%{?rhel} -eq 6 ] && echo /%{_lib} || echo %{_libdir})

Summary:	Internationalized Domain Name support library
Name:		libidn
Version:	1.28
Release:	3%{?dist}
License:	(GPLv2+ or LGPLv3+) and GPLv3 and GFDL
Group:		System Environment/Libraries
URL:		http://www.gnu.org/software/libidn
Source0:	http://ftp.gnu.org/gnu/libidn/libidn-%{version}.tar.gz
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildRequires:	pkgconfig, gettext, libtool, symlinks
%if 0%{?fedora} > 20 || 0%{?rhel} > 7
BuildRequires:	hostname
%else
BuildRequires:	/bin/hostname
%endif
Requires(post): /sbin/install-info, /sbin/ldconfig
Requires(preun):/sbin/install-info
# gnulib is a copylib; bundling is allowed
Provides:	bundled(gnulib)

%description
GNU Libidn is an implementation of the Stringprep, Punycode and IDNA
specifications defined by the IETF Internationalized Domain Names (IDN) working
group, used for internationalized domain names.

%if %{advanced_emacs}
%package -n emacs-libidn
Summary:	GNU Emacs libidn support files
License:	GPLv3+
BuildRequires:	emacs
Requires:	%{name} = %{version}-%{release}
Requires:	emacs(bin) >= %{_emacs_version}
BuildArch:	noarch

%description -n emacs-%{name}
This package includes libidn support files for GNU Emacs.
%endif

%package devel
Summary:	Development files for the libidn library
Group:		Development/Libraries
Requires:	%{name}%{?_isa} = %{version}-%{release}
Requires:	pkgconfig

%description devel
This package includes header files and libraries necessary for developing
programs that use the GNU libidn library.

%prep
%setup -q

# Avoid dependency on /usr/bin/perl for devel package
chmod -c -x contrib/doxygen/gdoc2doxygen

# Remove file we don't want packaging
rm contrib/doxygen/Doxyfile.orig

# Note that the libidn.info file deliberately includes different character
# encodings and hence it's inappropriate to convert it to UTF-8

%build
%configure \
%if %{advanced_emacs}
	--with-lispdir=%{_emacs_sitelispdir}/libidn \
%endif
	--disable-dependency-tracking \
	--disable-java \
	--disable-csharp \
	--libdir=%{library_dir}

# Kill bogus RPATHs
sed -i 's|^sys_lib_dlsearch_path_spec="/lib /usr/lib|sys_lib_dlsearch_path_spec="/%{_lib} %{_libdir}|' libtool

make %{?_smp_mflags} WARN_CFLAGS="-Wall" V=1

%install
rm -rf %{buildroot}
make \
	DESTDIR=%{buildroot} \
	INSTALL="install -p" \
	V=1 \
	WARN_CFLAGS="-Wall" \
	pkgconfigdir=%{_libdir}/pkgconfig \
	install

# Provide more examples
make %{?_smp_mflags} -C examples WARN_CFLAGS="-Wall" distclean

# Clean up docs
find doc -name "Makefile*" | xargs rm -f
rm -f %{buildroot}%{_datadir}/info/dir

# Fix up shared libraries if necessary
%if "%{library_dir}" != "%{_libdir}"

	# Remove existing libidn.so symlink
	rm %{buildroot}%{library_dir}/libidn.so

	# Create libidn.so symlink in %%{_libdir} instead
	mkdir -p %{buildroot}%{_libdir}
	library_so=%(echo %{buildroot}%{library_dir}/libidn.so.*.*)
	ln -sf ${library_so} %{buildroot}%{_libdir}/libidn.so
	symlinks -cs %{buildroot}%{_libdir}

	# Fix the .pc file to reference the directory that contains the .so
	sed -i -e 's|^libdir=.*$|libdir=%{_libdir}|' \
		%{buildroot}%{_libdir}/pkgconfig/libidn.pc
%endif

%if %{advanced_emacs}
%{_emacs_bytecompile} %{buildroot}%{_emacs_sitelispdir}/libidn/*.el
%endif

%find_lang %{name}

%check
make %{?_smp_mflags} -C tests WARN_CFLAGS="-Wall" check

%clean
rm -rf %{buildroot}

%post
/sbin/install-info %{_infodir}/%{name}.info %{_infodir}/dir || :
/sbin/ldconfig

%preun
[ $1 = 0 ] && /sbin/install-info --delete %{_infodir}/%{name}.info %{_infodir}/dir || :

%postun -p /sbin/ldconfig

%files -f %{name}.lang
%defattr(-,root,root,-)
# GPLv2+ or LGPLv3+
%{library_dir}/libidn.so.*
%exclude %{library_dir}/libidn.la
# GPLv3
%doc ChangeLog NEWS FAQ README THANKS COPYING*
%{_bindir}/idn
%if ! %{advanced_emacs}
%{_datadir}/emacs/site-lisp/
%endif
%{_infodir}/libidn.info.gz
%exclude %{_infodir}/libidn-components.png.gz
%{_mandir}/man1/idn.1*

%if %{advanced_emacs}
%files -n emacs-libidn
%defattr(-,root,root,-)
%{_emacs_sitelispdir}/libidn/
%endif

%files devel
%defattr(644,root,root,755)
# GPLv2+ or LGPLv3+
%{_includedir}/*.h
%exclude %{library_dir}/libidn.a
%{_libdir}/libidn.so
%{_libdir}/pkgconfig/*.pc
# GPLv3
%doc examples/ contrib/
%{_mandir}/man3/*
# GFDL (version 1.3 or later)
%doc doc/libidn.html
%doc doc/reference/libidn.pdf

%changelog
* Wed Jan 15 2014 Paul Howarth <paul@city-fan.org> 1.28-3
- BR: hostname package rather than /bin/hostname from F-21 as the latter is no
  longer provided in rawhide

* Sun Aug  4 2013 Paul Howarth <paul@city-fan.org> 1.28-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Jul 11 2013 Paul Howarth <paul@city-fan.org> 1.28-1
- Update to 1.28
  - Don't crash when string conversion from UTF-8 to locale fails
  - Fix java build failures
  - java: TestIDNA -a and -u logic was reversed, now fixed

* Sun Jun  9 2013 Paul Howarth <paul@city-fan.org> 1.27-1
- Update to 1.27
  - Java library can be built using Maven
  - Speed improvements
  - Update gnulib files and translations
- Make devel dependency arch-specific

* Sat Feb 23 2013 Paul Howarth <paul@city-fan.org> 1.26-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Mon Dec 17 2012 Paul Howarth <paul@city-fan.org> 1.26-1
- Update to 1.26
  - Propagate error on malloc failure
  - Fix out of bounds read access violation
  - Added Croatian translation
  - Updated Vietnamese translation
  - Permit usage of java binding by Apache projects
  - Improve tld self-tests
- BR: /bin/hostname (for configure test)

* Tue Jul 24 2012 Paul Howarth <paul@city-fan.org> 1.25-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Wed May 30 2012 Paul Howarth <paul@city-fan.org> 1.25-2
- Provide bundled(gnulib) (#821768)

* Thu May 24 2012 Paul Howarth <paul@city-fan.org> 1.25-1
- Update to 1.25
  - Fix build with MSVC related to _GL_ATTRIBUTE_CONST and _GL_ATTRIBUTE_PURE
  - Fix compiler warning about ignoring return value from fgets in examples
  - Ship with a valgrind suppressions file for the strlen issue in the tests
  - Update gnulib files and translations
- Build with V=1 so we can see the compiler flags being used

* Mon Apr  2 2012 Paul Howarth <paul@city-fan.org> 1.24-2
- From F-17/RHEL-7 onwards, install to %%{_libdir} rather than /%%{_lib}
  (https://fedoraproject.org/wiki/Features/UsrMove)
- Maintain upstream timestamps where possible

* Wed Jan 11 2012 Paul Howarth <paul@city-fan.org> 1.24-1
- Update to 1.24
  - Libraries are re-licensed from LGPLv2+ to dual-GPLv2+|LGPLv3+
  - Fix parallel Windows builds
  - libidn: Fix potential infloop in pr29 code
    (http://lists.gnu.org/archive/html/help-libidn/2012-01/msg00008.html)
  - libidn: Add 'const' keyword to 'stringprep_ucs4_nfkc_normalize' function
  - Sync glib NFKC code and improve copyright/license statements
  - Update gnulib files and translations

* Fri Nov 25 2011 Paul Howarth <paul@city-fan.org> 1.23-1
- Update to 1.23
  - stringprep.h: Now #include's sys/types.h instead of unistd.h for ssize_t
    (some systems e.g., Mingw with MSVC 9, do not have unistd.h)
  - idn-free.h: Protect prototypes with 'extern "C"' marker
  - doc: Update link to experimental TLD tables:
    the new link is <https://github.com/gnuthor/tldchk>
  - Update gnulib files and translations
  - QA: Improved cyclo output, update GTK-DOC files, various bugfixes

* Tue May 31 2011 Paul Howarth <paul@city-fan.org> 1.22-3
- Split emacs-libidn subpackage to avoid *.elc arch conflicts (#709136)

* Sun May 29 2011 Paul Howarth <paul@city-fan.org> 1.22-2
- Byte compile Emacs lisp files, require emacs-filesystem for dir ownership

* Thu May  5 2011 Paul Howarth <paul@city-fan.org> 1.22-1
- Update to 1.22
  - libidn: Add -liconv as static library requirement in libidn.pc, for MinGW
  - libidn: Fix memory leak in idna_to_ascii_4z when idna_to_ascii_4i fails
  - libidn: Ran clang-analyze on the code; fixed some dead
    assignments/initializations
  - build: Really distribute win32/libidn4win.mk

* Tue Apr 26 2011 Paul Howarth <paul@city-fan.org> 1.21-1
- Update to 1.21
  - build/gettext: Demand gettext >= 0.18.1 in order to get newer M4 files; the
    old M4 files associated with 0.17 caused problems on Solaris
    (http://thread.gmane.org/gmane.comp.lib.gnulib.bugs/25522)
  - build: Improve MinGW cross-compile makefile, see win32/libidn4win.mk
  - build: Visual Studio files fixed to define LIBIDN_BUILDING
- Nobody else likes macros for commands

* Wed Mar  2 2011 Paul Howarth <paul@city-fan.org> 1.20-1
- Update to 1.20
  - libidn: fix bug in ToUnicode to compare 'xn--' case-insensitively
    (http://bugs.debian.org/610617)
  - add self-test tst_idna3 to catch any regression of problem above
  - idn: only print copyright and license blurb when used interactively
    (http://bugs.debian.org/615947 and http://bugs.debian.org/615949)
  - update gnulib files and translations

* Mon Aug  2 2010 Paul Howarth <paul@city-fan.org> 1.19-2
- Move library to /%%{_lib} for F-9, EL-6 onwards (#283651)
- Don't package %%{_infodir}/libidn-components.png
- BR: symlinks

* Mon May 24 2010 Paul Howarth <paul@city-fan.org> 1.19-1
- Update to 1.19
  - fix typos in docs
  - add PDF version of API reference manual
  - update gnulib files
  - use valgrind -q in build to reduce verbosity

* Tue Feb 16 2010 Paul Howarth <paul@city-fan.org> 1.18-1
- Update to 1.18 (fix symbol export problem for a few variables)
- Fix doc file dependency on /usr/bin/perl for devel package

* Wed Jan 13 2010 Paul Howarth <paul@city-fan.org> 1.16-1
- Update to 1.16 (add a Maven pom.xml, not packaged)

* Tue Jun  9 2009 Paul Howarth <paul@city-fan.org> 1.15-1
- Update to 1.15
- * use c_strcasecmp instead of strcasecmp (spec requires ASCII comparison)
- * some java compiler warnings fixed
- * improved sections for the info manual
- No need to clean up info file sections any longer

* Mon Apr  6 2009 Paul Howarth <paul@city-fan.org> 1.14-1
- Update to 1.14 (test updates and extra data for Windows platform)

* Mon Mar  9 2009 Paul Howarth <paul@city-fan.org> 1.13-1
- Update to 1.13 (improvements in symbol visibility and dependencies)

* Mon Jan 26 2009 Paul Howarth <paul@city-fan.org> 1.12-1
- Update to 1.12
- Manual now licensed GFDL 1.3 or later
- Specify WARN_CFLAGS=-Wall to prevent the use of options unsupported on old
  releases

* Tue Oct 28 2008 Paul Howarth <paul@city-fan.org> 1.11-1
- Update to 1.11

* Wed Aug 27 2008 Paul Howarth <paul@city-fan.org> 1.10-1
- Update to 1.10
- Source is now on ftp.gnu.org

* Fri Jul  4 2008 Paul Howarth <paul@city-fan.org> 1.9-2
- Use /%%{_lib} rather than %%{_lib} in the bogus RPATH killer script

* Wed Jul  2 2008 Paul Howarth <paul@city-fan.org> 1.9-1
- Update to 1.9

* Thu Apr 24 2008 Paul Howarth <paul@city-fan.org> 1.8-1
- Update to 1.8

* Fri Apr 11 2008 Paul Howarth <paul@city-fan.org> 1.7-1
- Update to 1.7

* Tue Mar 25 2008 Paul Howarth <paul@city-fan.org> 1.6-1
- Update to 1.6

* Wed Feb 20 2008 Paul Howarth <paul@city-fan.org> 1.5-1
- Update to 1.5
- Using system libtool results in build failures, so hack the supplied libtool
  to prevent the generation of bogus RPATHs on 64-bit systems instead

* Fri Jan 11 2008 Paul Howarth <paul@city-fan.org> 1.4-1
- Update to 1.4

* Tue Dec 11 2007 Paul Howarth <paul@city-fan.org> 1.3-1
- Update to 1.3

* Tue Oct  2 2007 Paul Howarth <paul@city-fan.org> 1.2-1
- Update to 1.2

* Tue Sep 11 2007 Paul Howarth <paul@city-fan.org> 1.1-1
- Update to 1.1
- Clarify licensing in more detail

* Tue Jul 31 2007 Paul Howarth <paul@city-fan.org> 1.0-1
- Update to 1.0
- Add note regarding licensing in License: tag

* Thu May 31 2007 Paul Howarth <paul@city-fan.org> 0.6.14-1
- Update to 0.6.14
- Include %%{_infodir}/libidn-components.png.gz

* Thu Apr 26 2007 Paul Howarth <paul@city-fan.org> 0.6.12-1
- Update to 0.6.12

* Thu Mar 15 2007 Paul Howarth <paul@city-fan.org> 0.6.11-1
- Update to 0.6.11

* Fri Jan  5 2007 Paul Howarth <paul@city-fan.org> 0.6.10-1
- Update to 0.6.10

* Fri Dec  1 2006 Paul Howarth <paul@city-fan.org> 0.6.9-1
- Update to 0.6.9

* Fri Nov 17 2006 Paul Howarth <paul@city-fan.org> 0.6.8-3
- Let's try to remember to sign the package this time

* Thu Nov 16 2006 Paul Howarth <paul@city-fan.org> 0.6.8-2
- use non-GNU section in info directory (#209491)

* Thu Oct 19 2006 Paul Howarth <paul@city-fan.org> 0.6.8-1
- update to 0.6.8

* Thu Sep 14 2006 Paul Howarth <paul@city-fan.org> 0.6.7-1
- update to 0.6.7
- use system libtool to avoid rpath of /usr/lib64 in idn, provided that
  it supports all required options
- add note about encoding of info file

* Fri Aug 25 2006 Paul Howarth <paul@city-fan.org> 0.6.6-1
- update to 0.6.6

* Mon Jul 10 2006 Paul Howarth <paul@city-fan.org> 0.6.5-1
- update to 0.6.5

* Fri Jul  7 2006 Paul Howarth <paul@city-fan.org> 0.6.4-1
- update to 0.6.4
- was going to add valgrind buildreq for improved test coverage but some
  old distros I'd like to support (e.g. RHL9) don't have valgrind

* Thu Apr  6 2006 Paul Howarth <paul@city-fan.org> 0.6.3-2
- rewrite spec in Fedora Extras style
- add dist tag to facilitate separate build for Fedora Core 5 and later
  (#188006)
- exclude libtool archive and static library
- explicitly disable C# and Java bindings

* Wed Apr  5 2006 Paul Howarth <paul@city-fan.org> 0.6.3-1
- remove the unpackaged DLL if it gets installed

* Thu Mar  9 2006 Paul Howarth <paul@city-fan.org> 0.6.3-0
- update to 0.6.3

* Wed Feb  8 2006 Paul Howarth <paul@city-fan.org> 0.6.2-0
- update to 0.6.2

* Fri Dec  2 2005 Paul Howarth <paul@city-fan.org> 0.6.0-0
- update to 0.6.0

* Mon Oct 24 2005 Paul Howarth <paul@city-fan.org> 0.5.20-0
- update to 0.5.20

* Tue Sep 20 2005 Paul Howarth <paul@city-fan.org> 0.5.19-0
- update to 0.5.19

* Fri May 27 2005 Paul Howarth <paul@city-fan.org> 0.5.17-0
- update to 0.5.17

* Wed May 11 2005 Paul Howarth <paul@city-fan.org> 0.5.16-0
- update to 0.5.16

* Sun Mar 20 2005 Joe Orton <jorton@redhat.com> 0.5.15-1
- update to 0.5.15

* Fri Mar  4 2005 Joe Orton <jorton@redhat.com> 0.5.13-2
- rebuild

* Mon Jan 31 2005 Joe Orton <jorton@redhat.com> 0.5.13-1
- update to 0.5.13

* Sun Dec  5 2004 Joe Orton <jorton@redhat.com> 0.5.12-1
- update to 0.5.12

* Mon Nov 29 2004 Joe Orton <jorton@redhat.com> 0.5.11-1
- update to 0.5.11 (#141094)

* Tue Nov  9 2004 Joe Orton <jorton@redhat.com> 0.5.10-1
- update to 0.5.10
- buildroot cleanup fix (Robert Scheck)

* Mon Nov  8 2004 Joe Orton <jorton@redhat.com> 0.5.9-1
- update to 0.5.9 (#138296)

* Thu Oct  7 2004 Joe Orton <jorton@redhat.com> 0.5.6-1
- update to 0.5.6 (#134343)

* Thu Sep 30 2004 Miloslav Trmac <mitr@redhat.com> - 0.5.4-3
- Fix Group: (#134068)

* Tue Aug 31 2004 Joe Orton <jorton@redhat.com> 0.5.4-2
- move ldconfig from preun to postun (#131280)

* Sun Aug  8 2004 Joe Orton <jorton@redhat.com> 0.5.4-1
- update to 0.5.4 (#129341)

* Thu Jul 15 2004 Robert Scheck <redhat@linuxnetz.de> 0.5.2-1
- upgrade to 0.5.2, enabled i18n support and info files (#127906)

* Fri Jul  9 2004 Joe Orton <jorton@redhat.com> 0.5.1-1
- update to 0.5.1 (#127496)

* Mon Jun 28 2004 Joe Orton <jorton@redhat.com> 0.5.0-1
- update to 0.5.0 (#126836)

* Tue Jun 22 2004 Than Ngo <than@redhat.com> 0.4.9-2
- add prereq: /sbin/ldconfig
- move la file in main package

* Tue Jun 15 2004 Robert Scheck <redhat@linuxnetz.de> 0.4.9-1
- upgrade to 0.4.9 (#126353)

* Tue Jun 15 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Thu Apr 29 2004 Joe Orton <jorton@redhat.com> 0.4.4-1
- update to 0.4.4; remove contrib from -devel docs

* Thu Apr 29 2004 Joe Orton <jorton@redhat.com> 0.4.3-1
- update to 0.4.3, remove -rpath patch

* Tue Jan 27 2004 Joe Orton <jorton@redhat.com> 0.3.7-1
- update to 0.3.7, simplify

* Wed Jan 07 2004 Lenny Cartier <lenny@mandrakesoft.com> 0.3.6-1mdk
- 0.3.6

* Mon Dec 15 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 0.3.5-1mdk
- 0.3.5

* Sun Oct 19 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 0.3.3-2mdk
- drop the "soname fix" and use the correct way...

* Sat Oct 18 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 0.3.3-1mdk
- 0.3.3

* Mon Oct 13 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 0.3.2-1mdk
- initial cooker contrib
- used the package from PLD as a start point
